| Title: | Download and extract Entity-Attribute metadata into a CSV |
|---|---|
| Description: | Downloads and extracts Entity-Attribute metadata from EML documents stored in a DataONE Member Node |
| Authors: | Bryce Mecum <[email protected]> |
| Maintainer: | Bryce Mecum <[email protected]> |
| License: | Apache License 2.0 |
| Version: | 0.1.0 |
| Built: | 2026-06-03 09:01:39 UTC |
| Source: | https://github.com/amoeba/eatocsv |
This function uses the future package and therefore allows
downloads to happen in sequential order or parallel.
download_objects(node, pids, path = getwd(), ext = ".xml", overwrite = FALSE)download_objects(node, pids, path = getwd(), ext = ".xml", overwrite = FALSE)
node |
(CNode|MNode) The Node to download from |
pids |
(character) One ore more PIDs to download from the |
path |
(character) The destination directory for downloadd Objects |
ext |
(character) Optional. Specify a custom file extension to add to each downloaded file |
overwrite |
(boolean) Whether to overwrite existing files (TRUE) or not (FALSE) |
(list) A list of file paths for the downloaded files
Extract Entity-Attribute information from a set of EML records
ea_to_csv(paths, datetime = Sys.time())ea_to_csv(paths, datetime = Sys.time())
paths |
(character) Paths to one or more EML records to read from |
datetime |
(optional) Optional. Specify a query time to save with the resulting CSV |
(data.frame) A data.frame of Entity-Attribute information
Extract Entity-Attribute information from a set of EML records
extract_ea(paths, datetime = Sys.time())extract_ea(paths, datetime = Sys.time())
paths |
(character) Paths to one or more EML records to read from |
datetime |
(optional) Optional. Specify a query time to save with the resulting CSV |
(data.frame) A data.frame of Entity-Attribute information
Extract keywords from EML records
extract_keywords(paths, datetime = Sys.time())extract_keywords(paths, datetime = Sys.time())
paths |
(character) Paths to one or more EML records to read from |
datetime |
(optional) Optional. Specify a query time to save with the resulting CSV |
(data.frame) A data.frame of keywords, one row per keyword
Get Entity-Attribute Metadata for one or more Objects
get_object_ea(node, identifiers)get_object_ea(node, identifiers)
node |
(MNode|CNode) The Node where the Object(s) can be found |
identifiers |
The Object's identifier (PID) |
(data.frame) A table of entity attribute metadata
This is a custom routine that's probably overly aggressive
sanitize_filename(filenames)sanitize_filename(filenames)
filenames |
(character) One or more filenames to sanitized |
(character) The sanitized filenames